@@ -1,5 +1,5 @@
 # _*_coding:utf-8_*_
-
+from django.views.decorators.http import require_http_methods
 from rest_framework.views import APIView
 
 from xj_role.services.role_service import RoleService
@@ -13,9 +13,10 @@ from ..utils.user_wrapper import user_authentication_force_wrapper
 # 管理员添加用户
 class UserAdd(APIView):
 
+    @require_http_methods(['POST'])
     @user_authentication_force_wrapper
     @request_params_wrapper
-    def post(self, request, *args, request_params=None, **kwargs):
+    def add(self, *args, request_params=None, **kwargs):
         if request_params is None:
             request_params = {}
 
