@@ -14,9 +14,10 @@ from django.forms import model_to_dict
 import requests
 
 from main.settings import BASE_DIR
+from xj_role.services.user_group_service import UserGroupService
 from xj_user.services.wechat_service import WechatService
 from ..models import BaseInfo
-from ..services.user_detail_info_service import DetailInfoService
+from ..services.user_detail_info_service import DetailInfoService, write_to_log
 from ..services.user_relate_service import UserRelateToUserService
 from ..utils.custom_tool import get_short_id
 from ..utils.j_config import JConfig
@@ -65,9 +66,9 @@ class UserSmsService:
         )
         return user_info.json()
 
-    def phone_login(self, phone, login_code, sso_serve_id=None, detail_params=None):
-        if detail_params is None:
-            detail_params = {}
+    def phone_login(self, phone, login_code, sso_serve_id=None, other_params=None):
+        if other_params is None:
+            other_params = {}
         # 根据手机号获取用户
         current_user = BaseInfo.objects.filter(phone=phone).first()
         # print(">>>用户信息 current_user ", current_user)
@@ -100,13 +101,22 @@ class UserSmsService:
 
             # 用户第一次登录即注册，允许添加用户的详细信息
             try:
-                detail_params.setdefault("user_id", user_info.get('id', None))
-                detail_params.setdefault("score", "5")  # 用户评分初始化，镖行天下业务逻辑
-                data, detail_err = DetailInfoService.create_or_update_detail(detail_params)
+                other_params.setdefault("user_id", user_info.get('id', None))
+                other_params.setdefault("score", "5")  # 用户评分初始化，镖行天下业务逻辑
+                data, detail_err = DetailInfoService.create_or_update_detail(other_params)
                 if detail_err:
                     raise Exception(detail_err)
             except Exception as e:
                 logger.error('---首次登录写入用户详细信息异常：' + str(e) + '---')
+                write_to_log(prefix="用户手机号登录,绑定详细信息异常", err_obj=e)
+
+            # 用户第一次登录即注册，绑定用户的分组ID
+            try:
+                group_id = other_params.get("group_id")
+                if group_id:
+                    UserGroupService.user_bind_group(user_id=user_info.get('id', None), group_id=group_id)
+            except Exception as err:
+                write_to_log(prefix="用户手机号登录，绑定部门ID异常", err_obj=err)
 
             # 检验单点登录信息
             sso_set, sso_err = WechatService.sso_verify(sso_serve_id, user_info.get('id', None), sub_appid, openid,
@@ -141,12 +151,12 @@ class UserSmsService:
                 return None, auth_err
 
             # 绑定用户关系 邀请关系和收益关系
-        data, relate_err = UserRelateToUserService.bind_bxtx_relate(params=detail_params, user_info=user_info)
+        data, relate_err = UserRelateToUserService.bind_bxtx_relate(params=other_params, user_info=user_info)
         if relate_err:
             logger.error(
                 '绑定用户关系异常：' + str(relate_err) +
                 ' \n当前用户ID:' + str(user_info.get("id", "")) +
-                '\n detail_params:' + json.dumps(detail_params)
+                '\n detail_params:' + json.dumps(other_params)
             )
 
         return {'token': auth_set.token, 'user_info': user_info}, None
