@@ -6,6 +6,7 @@ from django.urls import re_path
 # from django.views.generic import TemplateView
 # from django.contrib.auth.decorators import login_required
 from xj_user.apis import user_login_wechat_app
+from xj_user.apis.user_add import UserAdd
 from .apis import user_add
 from .apis import user_contact_book
 from .apis import user_detail_info
@@ -44,7 +45,7 @@ urlpatterns = [
     re_path(r'^list/?$', user_list.UserListAPIView.as_view(), ),  # 用户列表
     re_path(r'^info/?$', user_info.UserInfo.as_view(), ),
     re_path(r'^edit/?$', user_edit.UserEdit.user_edit, ),
-    re_path(r'^add/?$', user_add.UserAdd.as_view(), ),  # 管理员添加用户
+    # re_path(r'^add/?$', user_add.UserAdd.as_view(), ),  # 管理员添加用户
     re_path(r'^delete/?$', user_edit.UserEdit.as_view(), ),  # 管理员添加用户
 
     re_path(r'^password/?$', user_password.UserPassword.as_view(), ),
@@ -58,6 +59,8 @@ urlpatterns = [
     # re_path(r'^group_tree/?$', user_group_tree.UserGroupTree.as_view(), ),
     re_path(r'^detail_extend_fields/?$', user_detail_info.UserDetailExtendFields.as_view(), ),
 
+    re_path(r'^add/?$', UserAdd.add, ),  # 管理员添加用户
+
     # 分组
     # re_path(r'^group/?$', user_group.GroupAPIView.as_view(), ),
     # re_path(r'^group_list/?$', user_group.GroupAPIView.list, ),
